pub struct RunQueues { /* private fields */ }Expand description
The self-referencing struct.
Implementations
Sourceimpl RunQueues
impl RunQueues
Sourcepub fn with_config<'outer_borrow, ReturnType>(
&'outer_borrow self,
user: impl for<'this> FnOnce(&'outer_borrow Arc<QueuesConfig>) -> ReturnType,
) -> ReturnType
pub fn with_config<'outer_borrow, ReturnType>( &'outer_borrow self, user: impl for<'this> FnOnce(&'outer_borrow Arc<QueuesConfig>) -> ReturnType, ) -> ReturnType
Provides limited immutable access to config. This method was generated because the contents of config are immutably borrowed by other fields.
Sourcepub fn borrow_config<'this>(&'this self) -> &'this Arc<QueuesConfig>
pub fn borrow_config<'this>(&'this self) -> &'this Arc<QueuesConfig>
Provides limited immutable access to config. This method was generated because the contents of config are immutably borrowed by other fields.
Sourceimpl RunQueues
impl RunQueues
Sourcepub fn all_queues<'s>(&'s self) -> impl Iterator<Item = &'s RunQueue<'s>>
pub fn all_queues<'s>(&'s self) -> impl Iterator<Item = &'s RunQueue<'s>>
Retuns all queues of all kinds; e.g. for migrating items.
pub fn pipeline(&self) -> &[RunQueue<'_>]
pub fn erroneous_jobs_queue(&self) -> Option<&RunQueue<'_>>
pub fn done_jobs_queue(&self) -> Option<&RunQueue<'_>>
pub fn first(&self) -> &RunQueue<'_>
pub fn data<'run_queues>( &'run_queues self, ) -> Result<RunQueuesData<'run_queues>>
Sourcepub fn get_run_queue_with_next_by_name(
&self,
file_name: &ProperFilename,
) -> Option<RunQueueWithNext<'_, '_>>
pub fn get_run_queue_with_next_by_name( &self, file_name: &ProperFilename, ) -> Option<RunQueueWithNext<'_, '_>>
Also returns the queue following the requested one, if any
pub fn open( config: Arc<QueuesConfig>, create_dirs_if_not_exist: bool, global_app_state_dir: &GlobalAppStateDir, signal_change: Option<PollingSignalsSender>, ) -> Result<Self>