pub struct RunQueuesData<'run_queues> { /* private fields */ }Expand description
A loaded copy of the on-disk data, for on-the-fly indexing/multiple traversal
Implementations
Sourceimpl<'run_queues> RunQueuesData<'run_queues>
impl<'run_queues> RunQueuesData<'run_queues>
Sourcepub fn run_queues(&self) -> &'run_queues RunQueues
pub fn run_queues(&self) -> &'run_queues RunQueues
For things to be run from e.g. run_job
(e.g. regenerate_index_files function)
Sourcepub fn jobs_by_commit_id(&self, commit_id: &GitHash) -> &[(usize, usize)]
pub fn jobs_by_commit_id(&self, commit_id: &GitHash) -> &[(usize, usize)]
Values are (index in pipeline_data, index within its queue_data)
pub fn have_job_with_commit_id(&self, commit_id: &GitHash) -> bool
Sourcepub fn run_queue_with_nexts<'s>(
&'s self,
) -> impl Iterator<Item = RunQueueDataWithNext<'run_queues, 'run_queues, 's>>
pub fn run_queue_with_nexts<'s>( &'s self, ) -> impl Iterator<Item = RunQueueDataWithNext<'run_queues, 'run_queues, 's>>
The RunQueueDatas paired with their successor (still in the
original, configured, order)
Sourcepub fn run_next_job<'s, 'conf, 'r, 'rc>(
&'s self,
job_runner: JobRunner<'_>,
run_context: &mut RunContext,
) -> Result<Option<(&'s BenchmarkingJob, JobStatus)>>
pub fn run_next_job<'s, 'conf, 'r, 'rc>( &'s self, job_runner: JobRunner<'_>, run_context: &mut RunContext, ) -> Result<Option<(&'s BenchmarkingJob, JobStatus)>>
Run the first or most prioritized job in the queues. Returns the job and its status after running it if one was found, None if all runnable queues are empty.
This method needs to be run in a loop forever for daemon style
processing. The reason this doesn’t do the looping inside is
to allow for a reload of the queue config and then
queues. current_stop_start, if given, represents an active
stop_start command that was run with stop and now needs a
start when the next running action does not require the same
command to be stoped. Likewise, this method returns the
active stop_start command, if any, by the time it
returns. The caller should pass that back into this method on
the next iteration. Using SliceOrBox to allow carrying it over
a config reload. now should be the current time (at least is
understood as such), get it via get_now_chrono() right
before calling this method.